[Bf-blender-cvs] [eef18d39cbf] blender2.8: Fix broken set collection offset from cursor operator.

Brecht Van Lommel noreply at git.blender.org
Fri Jun 1 17:15:03 CEST 2018


Commit: eef18d39cbf0e50ba18d28f52f57689ad0701c16
Author: Brecht Van Lommel
Date:   Fri Jun 1 16:10:48 2018 +0200
Branches: blender2.8
https://developer.blender.org/rBeef18d39cbf0e50ba18d28f52f57689ad0701c16

Fix broken set collection offset from cursor operator.

===================================================================

M	release/scripts/startup/bl_operators/object.py

===================================================================

diff --git a/release/scripts/startup/bl_operators/object.py b/release/scripts/startup/bl_operators/object.py
index 5fd54eceb25..0959cbec448 100644
--- a/release/scripts/startup/bl_operators/object.py
+++ b/release/scripts/startup/bl_operators/object.py
@@ -865,7 +865,7 @@ class TransformsToDeltasAnim(Operator):
 
 
 class DupliOffsetFromCursor(Operator):
     """Set offset used for DupliGroup based on cursor position"""
     bl_idname = "object.dupli_offset_from_cursor"
     bl_label = "Set Offset From Cursor"
     bl_options = {'INTERNAL', 'UNDO'}
@@ -876,9 +876,9 @@ class DupliOffsetFromCursor(Operator):
 
     def execute(self, context):
         scene = context.scene
-        group = context.group
+        collection = context.collection
 
-        group.dupli_offset = scene.cursor_location
+        collection.dupli_offset = scene.cursor_location
 
         return {'FINISHED'}
@@ -865,7 +865,7 @@ class TransformsToDeltasAnim(Operator):
 
 class DupliOffsetFromCursor(Operator):
-    """Set offset used for DupliGroup based on cursor position"""
+    """Set offset used for collection instances based on cursor position"""
     bl_idname = "object.dupli_offset_from_cursor"
     bl_label = "Set Offset From Cursor"



More information about the Bf-blender-cvs mailing list